send method
Sends an HTTP request and asynchronously returns the response.
Implementers should call BaseRequest.finalize to get the body of the
request as a ByteStream. They shouldn't make any assumptions about the
state of the stream; it could have data written to it asynchronously at a
later point, or it could already be closed when it's returned. Any
internal HTTP errors should be wrapped as ClientExceptions.
Implementation
@override
Future<http.StreamedResponse> send(http.BaseRequest request) {
if (bearerToken != null && bearerToken!.isNotEmpty) {
request.headers['Authorization'] = 'Bearer $bearerToken';
}
if (additionalHeaders != null) {
for (var entry in additionalHeaders!.entries) {
if (entry.value != null && entry.value!.isNotEmpty) {
request.headers[entry.key] = entry.value!;
}
}
}
return _inner.send(request);
}